Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1033)

Unified Diff: sdk/lib/_internal/pub/lib/src/barback/source_directory.dart

Issue 238443002: Rename BuildDirectory -> SourceDirectory. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub/lib/src/barback/source_directory.dart
diff --git a/sdk/lib/_internal/pub/lib/src/barback/build_directory.dart b/sdk/lib/_internal/pub/lib/src/barback/source_directory.dart
similarity index 81%
rename from sdk/lib/_internal/pub/lib/src/barback/build_directory.dart
rename to sdk/lib/_internal/pub/lib/src/barback/source_directory.dart
index c01da046dc1eaf49195f2280a0e4f72161888755..725c4fcb40375d26b1c6e8de9265ed496c4b63f7 100644
--- a/sdk/lib/_internal/pub/lib/src/barback/build_directory.dart
+++ b/sdk/lib/_internal/pub/lib/src/barback/source_directory.dart
@@ -2,21 +2,19 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library pub.barback.build_environment;
+library pub.barback.source_directory;
import 'dart:async';
import 'package:watcher/watcher.dart';
-import 'build_environment.dart';
+import 'asset_environment.dart';
import 'barback_server.dart';
-// TODO(rnystrom): Rename to "SourceDirectory" and clean up various doc
-// comments that refer to "build directories" to use "source directory".
/// A directory in the entrypoint package whose contents have been made
/// available to barback and that are bound to a server.
-class BuildDirectory {
- final BuildEnvironment _environment;
+class SourceDirectory {
+ final AssetEnvironment _environment;
/// The relative directory path within the package.
final String directory;
@@ -40,7 +38,7 @@ class BuildDirectory {
/// If the directory is not being watched, this will be `null`.
StreamSubscription<WatchEvent> watchSubscription;
- BuildDirectory(this._environment, this.directory, this.hostname, this.port);
+ SourceDirectory(this._environment, this.directory, this.hostname, this.port);
/// Binds a server running on [hostname]:[port] to this directory.
Future<BarbackServer> serve() {
@@ -51,7 +49,7 @@ class BuildDirectory {
});
}
/// Removes the build directory from the build environment.
///
/// Closes the server, removes the assets from barback, and stops watching it.
Future close() {
@@ -51,7 +49,7 @@ class BuildDirectory {
});
}
- /// Removes the build directory from the build environment.
+ /// Removes the source directory from the build environment.
///
/// Closes the server, removes the assets from barback, and stops watching it.

Powered by Google App Engine
This is Rietveld 408576698